Package: ruminate
Title: A Pharmacometrics Data Transformation and Analysis Tool
Version: 0.3.2
Authors@R: 
    person("John", "Harrold", , "john.m.harrold@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-2052-4373"))
Description: Exploration of pharmacometrics data involves both general tools (transformation and plotting) and specific techniques (non-compartmental analysis). This kind of exploration is generally accomplished by utilizing different packages. The purpose of 'ruminate' is to create a 'shiny' interface to make these tools more broadly available while creating reproducible results.
License: BSD_2_clause + file LICENSE
BugReports: https://github.com/john-harrold/ruminate/issues
URL: https://ruminate.ubiquity.tools/
Encoding: UTF-8
Depends: R (>= 4.2.0)
Imports: digest, dplyr, DT, flextable, formods (>= 0.2.0), ggplot2,
        onbrand (>= 1.0.3), PKNCA (>= 0.10.2), plotly, rhandsontable,
        rlang, shiny, shinyAce, shinyWidgets, stats, stringr, tidyr,
        utils, yaml, zip
Suggests: babelmixr2, cli, clipr, gridExtra, knitr, nlmixr2lib(>=
        0.3.0), nonmem2rx, nlmixr2(>= 3.0.0), prompter, rmarkdown,
        readxl, rxode2 (>= 3.0.0), shinybusy, shinydashboard, testthat
        (>= 3.0.0), ubiquity
RoxygenNote: 7.3.2
Config/testthat/edition: 3
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-11-03 14:33:15 UTC; jmh
Author: John Harrold [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-2052-4373>)
Maintainer: John Harrold <john.m.harrold@gmail.com>
Repository: CRAN
Date/Publication: 2025-11-04 05:50:02 UTC
Built: R 4.6.0; ; 2026-04-25 13:59:43 UTC; unix
